@@ -1,20 +1,16 @@
 # Copyright (c) 2018 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
 
-from UM.Logger import Logger
 from cura.Machines.Models.BaseMaterialsModel import BaseMaterialsModel
 
+##  Model that shows the list of favorite materials.
 class FavoriteMaterialsModel(BaseMaterialsModel):
-
     def __init__(self, parent = None):
         super().__init__(parent)
         self._update()
 
     def _update(self):
-
-        # Perform standard check and reset if the check fails
         if not self._canUpdate():
-            self.setItems([])
             return
 
         # Get updated list of favorites
