@@ -118,7 +118,7 @@ class GlobalStack(CuraContainerStack):
     ##  \sa configuredConnectionTypes
     def removeConfiguredConnectionType(self, connection_type: int) -> None:
         configured_connection_types = self.configuredConnectionTypes
-        if connection_type in self.configured_connection_types:
+        if connection_type in configured_connection_types:
             # Store the values as a string.
             configured_connection_types.remove(connection_type)
             self.setMetaDataEntry("connection_type", ",".join([str(c_type) for c_type in configured_connection_types]))
@@ -302,6 +302,17 @@ class GlobalStack(CuraContainerStack):
             Logger.log("w", "Firmware file %s not found.", hex_file)
             return ""
 
+    def getName(self) -> str:
+        return self._metadata.get("group_name", self._metadata.get("name", ""))
+
+    def setName(self, name: "str") -> None:
+        super().setName(name)
+
+    nameChanged = pyqtSignal()
+    name = pyqtProperty(str, fget=getName, fset=setName, notify=nameChanged)
+
+
+
 ## private:
 global_stack_mime = MimeType(
     name = "application/x-cura-globalstack",
